// -*- C++ -*-
/*!
 * @file  Camera_Switch.cpp
 * @brief ModuleDescription
 * @date $Date$
 *
 * $Id$
 */

#include "Camera_Switch.h"

// Module specification
// <rtc-template block="module_spec">
static const char* camera_switch_spec[] =
  {
    "implementation_id", "Camera_Switch",
    "type_name",         "Camera_Switch",
    "description",       "ModuleDescription",
    "version",           "1.0.0",
    "vendor",            "YukiTakamido",
    "category",          "Category",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
Camera_Switch::Camera_Switch(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_cameraImage1In("cameraImage1", m_cameraImage1),
    m_cameraImage2In("cameraImage2", m_cameraImage2),
    m_switchCameraIn("switchCamera", m_switchCamera),
    m_cameraImageOut("cameraImage", m_cameraImage)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
Camera_Switch::~Camera_Switch()
{
}



RTC::ReturnCode_t Camera_Switch::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("cameraImage1", m_cameraImage1In);
  addInPort("cameraImage2", m_cameraImage2In);
  addInPort("switchCamera", m_switchCameraIn);
  
  // Set OutPort buffer
  addOutPort("cameraImage", m_cameraImageOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // </rtc-template>
  
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t Camera_Switch::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Camera_Switch::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
								
/*
RTC::ReturnCode_t Camera_Switch::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t Camera_Switch::onActivated(RTC::UniqueId ec_id)
{
	CameraID = 1;
  return RTC::RTC_OK;
}


RTC::ReturnCode_t Camera_Switch::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t Camera_Switch::onExecute(RTC::UniqueId ec_id)
	{
	
		std::cout << "Camera ID is " << CameraID << std::endl;
		if (m_switchCameraIn.isNew())
		{
			m_switchCameraIn.read();
			CameraID = m_switchCamera.data;
		}
		if (m_cameraImage1In.isNew())
		{

			while (!m_cameraImage1In.isEmpty())
			{
				m_cameraImage1In.read();
			}
		}

		if (m_cameraImage2In.isNew())
		{

			while (!m_cameraImage2In.isEmpty())
			{
				m_cameraImage2In.read();
			}
		
		}
		if (CameraID == 1)
		{
		
				m_cameraImage = m_cameraImage1;
				m_cameraImageOut.write();
		}
		else if (CameraID == 2)
		{
			m_cameraImage = m_cameraImage2;
			m_cameraImageOut.write();
		}

	
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t Camera_Switch::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Camera_Switch::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Camera_Switch::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Camera_Switch::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Camera_Switch::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void Camera_SwitchInit(RTC::Manager* manager)
  {
    coil::Properties profile(camera_switch_spec);
    manager->registerFactory(profile,
                             RTC::Create<Camera_Switch>,
                             RTC::Delete<Camera_Switch>);
  }
  
};


